#pragma once

#include "DrawingSurface.h"
#include "DrawingContext.h"
#include "AbstractPainter.h"
#include "Scene.h"

#include "SvgConverter.h"
#include "SvgWriter.h"
#include "SvgDocument.h"

#include "Image.h"
#include "PngWriter.h"

#include "File.h"

class TestRenderer
{
public:
	TestRenderer(unsigned width = 1000, unsigned height = 1000)
	{
		mSurface = std::make_unique<DrawingSurface>();
		mSurface->setSize(width, height);

		mDrawingContext = std::make_unique<DrawingContext>(mSurface.get());
	}

	Scene* getScene() const
	{
		return mSurface->getScene();
	}

	void write(const Path& path)
	{
		mDrawingContext->paint();

		auto image = mSurface->getImage();

		PngWriter writer;
		writer.setPath(path);
		writer.write(image);
	}

	void writeSvg(const Path& path)
	{
		SvgConverter converter;
		auto svg_document = converter.convert(mSurface->getScene());

		SvgWriter writer;
		auto svg_content = writer.toString(svg_document.get());

		File svg_file(path);
		svg_file.writeText(svg_content);
	}

private:
	std::unique_ptr<DrawingSurface> mSurface;
	std::unique_ptr<DrawingContext> mDrawingContext;
};